From: Marek Vasut <marek.vasut@gmail.com>
To: u-boot@lists.denx.de
Subject: [U-Boot] [PATCH 03/11] FEC: Kill mode select FIXME's
Date: Mon, 12 Sep 2011 06:05:31 +0200 [thread overview]
Message-ID: <1315800339-19823-4-git-send-email-marek.vasut@gmail.com> (raw)
In-Reply-To: <1315800339-19823-1-git-send-email-marek.vasut@gmail.com>
Signed-off-by: Marek Vasut <marek.vasut@gmail.com>
Cc: Ben Warren <biggerbadderben@gmail.com>
Cc: Stefano Babic <sbabic@denx.de>
Cc: Wolfgang Denk <wd@denx.de>
Cc: Detlev Zundel <dzu@denx.de>
---
drivers/net/fec_mxc.c | 26 ++++++++++++++------------
1 files changed, 14 insertions(+), 12 deletions(-)
diff --git a/drivers/net/fec_mxc.c b/drivers/net/fec_mxc.c
index 8e0d30a..9a99272 100644
--- a/drivers/net/fec_mxc.c
+++ b/drivers/net/fec_mxc.c
@@ -400,6 +400,7 @@ static int fec_init(struct eth_device *dev, bd_t* bd)
{
uint32_t base;
struct fec_priv *fec = (struct fec_priv *)dev->priv;
+ uint32_t rcntrl;
/* Initialize MAC address */
fec_set_hwaddr(dev);
@@ -442,19 +443,19 @@ static int fec_init(struct eth_device *dev, bd_t* bd)
/*
* Set FEC-Lite receive control register(R_CNTRL):
*/
- if (fec->xcv_type == SEVENWIRE) {
- /*
- * Frame length=1518; 7-wire mode
- */
- writel(0x05ee0020, &fec->eth->r_cntrl); /* FIXME 0x05ee0000 */
- } else {
- /*
- * Frame length=1518; MII mode;
- */
- writel(0x05ee0024, &fec->eth->r_cntrl); /* FIXME 0x05ee0004 */
+ /* Start with frame length = 1518, common for all modes. */
+ rcntrl = PKTSIZE << FEC_RCNTRL_MAX_FL_SHIFT;
+ if (fec->xcv_type == SEVENWIRE)
+ rcntrl |= FEC_RCNTRL_FCE;
+ else /* MII mode */
+ rcntrl |= FEC_RCNTRL_FCE | FEC_RCNTRL_MII_MODE;
+
+ writel(rcntrl, &fec->eth->r_cntrl);
+
+ if (fec->xcv_type == MII10 || fec->xcv_type == MII100)
fec_mii_setspeed(fec);
- }
+
/*
* Set Opcode/Pause Duration Register
*/
@@ -731,7 +732,8 @@ static int fec_probe(bd_t *bd)
/*
* Frame length=1518; MII mode;
*/
- writel(0x05ee0024, &fec->eth->r_cntrl); /* FIXME 0x05ee0004 */
+ writel((PKTSIZE << FEC_RCNTRL_MAX_FL_SHIFT) | FEC_RCNTRL_FCE |
+ FEC_RCNTRL_MII_MODE, &fec->eth->r_cntrl);
fec_mii_setspeed(fec);
sprintf(edev->name, "FEC");
--
1.7.5.4
next prev parent reply other threads:[~2011-09-12 4:05 UTC|newest]
Thread overview: 27+ messages / expand[flat|nested] mbox.gz Atom feed top
2011-09-12 4:05 [U-Boot] [PATCH 00/11 V2] Support for both FEC interfaces on i.MX28 Marek Vasut
2011-09-12 4:05 ` [U-Boot] [PATCH 01/11] FEC: Use proper accessor to read register in debug call Marek Vasut
2011-09-22 10:55 ` Stefano Babic
2011-09-12 4:05 ` [U-Boot] [PATCH 02/11] FEC: Use defined constant instead of magic number Marek Vasut
2011-09-22 10:57 ` Stefano Babic
2011-09-12 4:05 ` Marek Vasut [this message]
2011-09-22 10:58 ` [U-Boot] [PATCH 03/11] FEC: Kill mode select FIXME's Stefano Babic
2011-09-12 4:05 ` [U-Boot] [PATCH 04/11] FEC: Add RMII mode support Marek Vasut
2011-09-22 10:58 ` Stefano Babic
2011-09-12 4:05 ` [U-Boot] [PATCH 05/11] FEC: Allow selection of MII mode via CONFIG_FEC_XCV_TYPE Marek Vasut
2011-09-22 10:59 ` Stefano Babic
2011-09-12 4:05 ` [U-Boot] [PATCH 06/11] FEC: Abstract access to fec->eth in MII operations Marek Vasut
2011-09-22 10:59 ` Stefano Babic
2011-09-12 4:05 ` [U-Boot] [PATCH 07/11] FEC: Allow multiple FECes Marek Vasut
2011-09-15 23:13 ` [U-Boot] [PATCH V2] " Marek Vasut
2011-09-22 10:57 ` Stefano Babic
2011-09-12 4:05 ` [U-Boot] [PATCH 08/11] FEC: Allow registering MII postconfiguration callback Marek Vasut
2011-09-22 11:00 ` Stefano Babic
2011-09-12 4:05 ` [U-Boot] [PATCH 09/11] FEC: Add timeout for chip reset Marek Vasut
2011-09-22 11:01 ` Stefano Babic
2011-09-12 4:05 ` [U-Boot] [PATCH 10/11] FEC: Squish "got MAC from fuse" message, make it debug() Marek Vasut
2011-09-22 11:01 ` Stefano Babic
2011-09-12 4:05 ` [U-Boot] [PATCH 11/11] FEC: Move imx_get_mac_from_fuse() definition to fec_mxc.h Marek Vasut
2011-09-22 11:02 ` Stefano Babic
-- strict thread matches above, loose matches on Subject: below --
2011-09-08 20:37 [U-Boot] [PATCH 00/11] Support for both FEC interfaces on i.MX28 Marek Vasut
2011-09-08 20:37 ` [U-Boot] [PATCH 03/11] FEC: Kill mode select FIXME's Marek Vasut
2011-09-09 0:48 ` Mike Frysinger
2011-09-09 12:19 ` Marek Vasut
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=1315800339-19823-4-git-send-email-marek.vasut@gmail.com \
--to=marek.vasut@gmail.com \
--cc=u-boot@lists.denx.de \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox